function [cohesion, FibCrackIn] = CompSW(FibCrackS, FibCrackIn, FibCrackPar, eta, sc, src, dc)

% function calculates fiber - bridging cohesion force
%
% in:   FibCrackS - parameters on short embedded side (see SelFib.m)
%       FibCrackIn - pulling and rupture parameters (see SelFib.m)
%       FibCrackPar - material parameters (see SelFib.m)
%       eta - 
%       sc - [-] snubbing coefficient
%       src - [-] strength reduction coefficient
%       dc - increment of crack opening
% out:  cohesion
%            Column 1 - u - displacement [mm]
%            Column 2 - P - force [kN]
%       FibCrackIn
%            Column 1 - rupture parameter
%            Column 2 - pulling parameter


n = size(FibCrackS,1);
% maxL = max(FibCrackS(:,1));

j = 1;
cohesion = zeros(1,2);
for COD = 0:dc:max(FibCrackS(:, 1))*1.5
	P = 0;
	for i=1:n
		Ps = 0;
		if (FibCrackIn(i, 1) == 0 && FibCrackIn(i, 2) == 0)
			if (COD <= FibCrackS(i, 2) )
				Ps = Pdeb(COD, FibCrackPar(i, 1), FibCrackPar(i, 4), FibCrackPar(i, 6), FibCrackPar(i, 7), eta) * exp(sc*  FibCrackPar(i, 2) );
			elseif (COD <= FibCrackS(i, 1) + FibCrackS(i, 2) )
				Ps = Ppull(COD, FibCrackPar(i, 1), FibCrackS(i, 1), FibCrackS(i, 2), FibCrackPar(i, 6), FibCrackPar(i, 8)) * exp(sc*  FibCrackPar(i, 2) );
			else
				FibCrackIn(i, 2) = 1;
			end
			if ( (Ps/(pi* FibCrackPar(i, 1)^2/4)) >= (FibCrackPar(i, 5) * exp(-src* FibCrackPar(i, 2) )) )
				Ps = 0;
				FibCrackIn(i, 1) = 1;
			end
			P = P+Ps;		
		end
	end
	cohesion(j, :) = [COD, P];
	j = j + 1;
end