function f = GenFibNoSaw(b, t, h, Lf, df, Vff)

% function generates fibres in volume of specimen
% (like in cast specimen)
%
% in:   b, t, h - dimension of specimen
%       Lf - length of fiber [Mean, StDev]
%       df - diameter of fiber [Mean, StDev]
%       Vff - volume fraction of fiber
% out:  f - table of fibers
%       Column 1 - initial x [mm]
%       Column 2 - initial  y [mm]
%       Column 3 - initial  z [mm]
%       Column 4 - end x [mm]
%       Column 5 - end y [mm]
%       Column 6 - end z [mm]
%       Column 7 - angle theta (angle from cross plane) [rad]
%       Column 8 - directional angle fi [rad]

Vf = pi*df(1,1)^2/4*Lf(1,1); % [mm3]
V = b*t*h; % [mm3]
n = round((V*Vff)/Vf); % number of fibers [-]

f = zeros(n,8);
parfor i=1:n
	Xp = random('Uniform',0,b);
	Yp = random('Uniform',0,t);
	Zp = random('Uniform',0,h);
	Lfc = random('Normal',Lf(1,1),Lf(2,1));
	pass=0;
	while (pass == 0)
		fi = random('Uniform',0,2*pi);
		theta = random('Uniform',-pi/2,pi/2);
		Xk = Xp+cos(fi)*cos(theta)*Lfc;
		Yk = Yp+sin(fi)*cos(theta)*Lfc;
		Zk = Zp+sin(theta)*Lfc;
		if ((Xk>=0) && (Xk<=b) && (Yk>=0) && (Yk<=t) && (Zk>=0) && (Zk<=h))
			pass = 1;
		end
	end
	f(i,:) = [Xp, Yp, Zp, Xk, Yk, Zk, theta, fi];
end