function FibMat = GenMat(FibGeo, df, Ef, ftf)

% function generates stochastic parameters of fiber
%
% in:   FibGeo - table of fibers (see GenFib.m)
%       df - diameter of fiber [Mean, StDev]
%       Ef - Young modulus of fiber [Mean, StDev]
%       ftf - Strength of fiber [Mean, StDev]
% out:  FibMat ... table of stochastic parameters of fibers
%       Column 1 - Length [mm]
%       Column 2 - Diameter [mm]
%       Column 3 - Young modulus [MPa]
%       Column 4 - Strength [MPa]

n = size(FibGeo,1);
FibMat = zeros(n, 4);

parfor i = 1:n
	Lff = sqrt( (FibGeo(i, 4)-FibGeo(i, 1))^2 + (FibGeo(i, 5)-FibGeo(i, 2))^2 + (FibGeo(i, 6)-FibGeo(i, 3))^2);
	dff = random('Normal', df(1,1), df(2,1));
	Eff = random('Normal', Ef(1,1), Ef(2,1));
	ftff = random('Normal', ftf(1,1), ftf(2,1));
	FibMat(i,:) = [Lff, dff, Eff, ftff];
end
